<?php

/**
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\FormTypesBundle\DependencyInjection;

use Misd\PhoneNumberBundle\Doctrine\DBAL\Types\PhoneNumberType;
use Symfony\Component\Config\FileLocator;
use Symfony\Component\DependencyInjection\ContainerBuilder;
use Symfony\Component\DependencyInjection\Extension\PrependExtensionInterface;
use Symfony\Component\DependencyInjection\Loader\PhpFileLoader;
use Symfony\Component\HttpKernel\DependencyInjection\Extension;

final class ChillFormTypesExtension extends Extension implements PrependExtensionInterface
{
    public function load(array $configs, ContainerBuilder $container)
    {
        $configuration = new Configuration();
        $config = $this->processConfiguration($configuration, $configs);

        $loader = new PhpFileLoader($container, new FileLocator(__DIR__ . '/../Resources'));
        $loader->load('services.php');
    }

    public function prepend(ContainerBuilder $container)
    {
        $configs = $container->getExtensionConfig($this->getAlias());
        $resolvingBag = $container->getParameterBag();
        $configs = $resolvingBag->resolveValue($configs);
        $config = $this->processConfiguration(new Configuration(), $configs);

        $container
            ->prependExtensionConfig(
                'framework',
                [
                    'http_client' => [
                        'scoped_clients' => [
                            'twilio_api' => [
                                'scope' => 'https://(lookups|api)\.twilio\.com',
                                'auth_basic' => $config['twilio']['sid'] . ':' . $config['twilio']['secret'],
                            ],
                        ],
                    ],
                ]
            );

        $container
            ->prependExtensionConfig(
                'doctrine',
                [
                    'dbal' => [
                        'types' => [
                            'phone_number' => PhoneNumberType::class,
                        ],
                    ],
                ]
            );
    }
}
