<?php

/**
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\FormTypesBundle\DependencyInjection;

use Symfony\Component\Config\Definition\Builder\TreeBuilder;
use Symfony\Component\Config\Definition\ConfigurationInterface;

final class Configuration implements ConfigurationInterface
{
    public function getConfigTreeBuilder()
    {
        $treeBuilder = new TreeBuilder('chill_form_types');

        if (method_exists($treeBuilder, 'getRootNode')) {
            $rootNode = $treeBuilder->getRootNode();
        } else {
            // BC layer for symfony/config 4.1 and older
            $rootNode = $treeBuilder->root('chill_form_types');
        }

        $rootNode
            ->children()
            ->arrayNode('twilio')
            ->addDefaultsIfNotSet()
            ->children()
            ->scalarNode('sid')
            ->defaultValue('%env(resolve:TWILIO_SID)%')
            ->end()
            ->scalarNode('secret')
            ->defaultValue('%env(resolve:TWILIO_SECRET)%')
            ->end()
            ->end()
            ->end();

        return $treeBuilder;
    }
}
