<?php

/**
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Symfony\Component\DependencyInjection\Loader\Configurator;

use Chill\FormTypesBundle\Service\PhoneNumberHelper;
use Chill\FormTypesBundle\Service\TwilioHttpClient;
use Symfony\Component\HttpKernel\HttpCache\Store;

return static function (ContainerConfigurator $container) {
    $services = $container
        ->services()
        ->defaults()
        ->autowire()
        ->autoconfigure();

    $services
        ->load('Chill\\FormTypesBundle\\', '../*')
        ->exclude('../src/{DependencyInjection,Entity,Resources,Tests,Kernel.php}');

    // This can be replaced by http_cache.store in Symfony 5.
    $services
        ->set('twilio.http_cache.store', Store::class)
        ->args([
            param('kernel.cache_dir') . '/http_cache',
        ]);

    $services
        ->set(TwilioHttpClient::class)
        ->arg('$store', service('twilio.http_cache.store'));

    $services
        ->set(PhoneNumberHelper::class)
        ->arg('$client', service(TwilioHttpClient::class));
};
