<?php

/**
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\FormTypesBundle\Service;

use libphonenumber\PhoneNumber;

interface PhoneNumberHelperInterface
{
    public function format(string $phonenumber): string;

    /**
     * Get type (mobile, landline, ...) for phone number.
     */
    public function getType(string $phonenumber): string;

    public function isTwilioEnabled(): bool;

    /**
     * Return true if the phonenumber is a landline or voip phone.  Return always true
     * if the validation is not configured.
     */
    public function isValidPhonenumberAny(PhoneNumber $phonenumber): bool;

    /**
     * Return true if the phonenumber is a landline or voip phone.  Return always true
     * if the validation is not configured.
     */
    public function isValidPhonenumberLandOrVoip(PhoneNumber $phonenumber): bool;

    /**
     * Return true if the phoennumber is a mobile phone. Return always true
     * if the validation is not configured.
     */
    public function isValidPhonenumberMobile(PhoneNumber $phonenumber): bool;
}
