<?php

/**
 * For the full copyright and license information, please view
 * the LICENSE file that was distributed with this source code.
 */

declare(strict_types=1);

namespace Chill\FormTypesBundle\Validation\Validator;

use Chill\FormTypesBundle\Service\PhoneNumberHelperInterface;
use Chill\FormTypesBundle\Validation\Constraint\PhonenumberConstraint;
use LogicException;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

final class PhoneNumberValidator extends ConstraintValidator
{
    protected PhoneNumberHelperInterface $phoneNumberHelper;

    public function __construct(
        PhoneNumberHelperInterface $phoneNumberHelper
    ) {
        $this->phoneNumberHelper = $phoneNumberHelper;
    }

    /**
     * @param Constraint|PhonenumberConstraint $constraint
     * @param mixed $value
     */
    public function validate($value, Constraint $constraint)
    {
        if (null === $value) {
            return;
        }

        if (false === $this->phoneNumberHelper->isTwilioEnabled()) {
            return;
        }

        $message = 'The phone number (%phonenumber%) must be of type: %type%';
        $isValid = true;

        switch ($constraint->type) {
            case 'landline':
                $isValid = $this->phoneNumberHelper->isValidPhonenumberLandOrVoip($value);

                break;

            case 'mobile':
                $isValid = $this->phoneNumberHelper->isValidPhonenumberMobile($value);

                break;

            case 'any':
                $isValid = $this->phoneNumberHelper->isValidPhonenumberAny($value);
                $message = 'The phone number (%phonenumber%) is invalid';

                break;

            default:
                throw new LogicException(
                    sprintf(
                        'The phone number type %s is not implemented.',
                        $constraint->type
                    )
                );
        }

        if (false === $isValid) {
            $this->context->addViolation($message, ['%type%' => $constraint->type, '%phonenumber%' => $value]);
        }
    }
}
